CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
44 lines
1.8 KiB
Plaintext
44 lines
1.8 KiB
Plaintext
// RUN: %clang_cc1 -triple x86_64 -verify=expected,dev \
|
|
// RUN: -verify-ignore-unexpected=note \
|
|
// RUN: -fopenmp -fopenmp-targets=amdgcn-amd-amdhsa -o - %s
|
|
// RUN: %clang_cc1 -triple x86_64 -verify -verify-ignore-unexpected=note\
|
|
// RUN: -fopenmp -fopenmp-targets=amdgcn-amd-amdhsa -o - -x c++ %s
|
|
// RUN: %clang_cc1 -triple x86_64 -verify=dev -verify-ignore-unexpected=note\
|
|
// RUN: -fcuda-is-device -o - %s
|
|
|
|
#if __CUDA__
|
|
#include "Inputs/cuda.h"
|
|
__device__ void cu_devf();
|
|
#endif
|
|
|
|
void bazz() {}
|
|
#pragma omp declare target to(bazz) device_type(nohost)
|
|
void bazzz() {bazz();}
|
|
#pragma omp declare target to(bazzz) device_type(nohost)
|
|
void any() {bazz();} // expected-error {{function with 'device_type(nohost)' is not available on host}}
|
|
void host1() {bazz();} // expected-error {{function with 'device_type(nohost)' is not available on host}}
|
|
#pragma omp declare target to(host1) device_type(host)
|
|
void host2() {bazz();} // expected-error {{function with 'device_type(nohost)' is not available on host}}
|
|
#pragma omp declare target to(host2)
|
|
void device() {host1();}
|
|
#pragma omp declare target to(device) device_type(nohost)
|
|
void host3() {host1();}
|
|
#pragma omp declare target to(host3)
|
|
|
|
#pragma omp declare target
|
|
void any1() {any();}
|
|
void any2() {host1();}
|
|
void any3() {device();} // expected-error {{function with 'device_type(nohost)' is not available on host}}
|
|
void any4() {any2();}
|
|
#pragma omp end declare target
|
|
|
|
void any5() {any();}
|
|
void any6() {host1();}
|
|
void any7() {device();} // expected-error {{function with 'device_type(nohost)' is not available on host}}
|
|
void any8() {any2();}
|
|
|
|
#if __CUDA__
|
|
void cu_hostf() { cu_devf(); } // dev-error {{no matching function for call to 'cu_devf'}}
|
|
__device__ void cu_devf2() { cu_hostf(); } // dev-error{{no matching function for call to 'cu_hostf'}}
|
|
#endif
|